@@ -665,7 +665,8 @@ static int state_scrub_process(struct snapraid_state* state, struct snapraid_par
 		log_fatal("DANGER! Unexpected data errors! The failing blocks are now marked as bad!\n");
 	if (io_error || silent_error) {
 		log_fatal("Use 'snapraid status' to list the bad blocks.\n");
-		log_fatal("Use 'snapraid -e fix' to recover.\n");
+		log_fatal("Use 'snapraid -e fix' to recover them.\n");
+		log_fatal("Use 'snapraid -p bad scrub' to recheck after fixing.\n");
 	}
 
 	log_tag("summary:error_file:%u\n", error);
